# Audit Plan: ADR-0.20.0-spec-triangle-sync

## Scope
- ADR: `docs/design/adr/pre-release/ADR-0.20.0-spec-triangle-sync/ADR-0.20.0-spec-triangle-sync.md`
- Generated: 2026-03-27

## Verification Commands
- `uv run gz test`
- `uv run gz lint`
- `uv run gz typecheck`
- `uv run mkdocs build --strict`

## Proof Output
- Directory: `docs/design/adr/pre-release/ADR-0.20.0-spec-triangle-sync/audit/proofs`
